sparky-info for Debian
---------------------

<Possible notes regarding this package - if none, delete this file.>

 -- pavroo <pavroo@onet.eu>  Sat, 14 Feb 2026 13:35:13 +0100
